"""Configs for pyrig.

All subclasses of ConfigFile in the configs package are automatically called.
"""

from pathlib import Path

from pyrig.dev import configs
from pyrig.dev.configs.base.base import PythonPackageConfigFile
from pyrig.dev.configs.pyproject import PyprojectConfigFile
from pyrig.utils.modules.module import to_path


class ConfigsConfigFile(PythonPackageConfigFile):
    """Config file for configs.py."""

    @classmethod
    def get_parent_path(cls) -> Path:
        """Get the path to the config file."""
        src_package = PyprojectConfigFile.get_package_name()
        builds_package = cls.get_module_name_replacing_start_module(
            configs, src_package
        )
        return to_path(builds_package, is_package=True)

    @classmethod
    def get_content_str(cls) -> str:
        """Get the content."""
        return '''"""Configs for pyrig.

All subclasses of ConfigFile in the configs package are automatically called.
"""
'''



"""Config File subclass that creates the builds dir and a build.py."""

from pathlib import Path

from pyrig.dev.artifacts import builder
from pyrig.dev.configs.base.base import PythonPackageConfigFile
from pyrig.dev.configs.pyproject import PyprojectConfigFile
from pyrig.utils.modules.module import to_path


class BuilderConfigFile(PythonPackageConfigFile):
    """Config File subclass that creates the dirs folder."""

    @classmethod
    def get_parent_path(cls) -> Path:
        """Get the path to the config file."""
        src_package = PyprojectConfigFile.get_package_name()
        builds_package = cls.get_module_name_replacing_start_module(
            builder, src_package
        )
        return to_path(builds_package, is_package=True)

    @classmethod
    def get_content_str(cls) -> str:
        """Get the content."""
        return '''"""Build script.

All subclasses of Builder in the builds package are automatically called.
"""
'''



"""Pytest configuration for pirig tests.

finds all the plugins in the tests directory and the package's testing module
and adds them to pytest_plugins. This way defining reusable fixtures is easy.
"""

from pathlib import Path

import pyrig
from pyrig.utils.modules.module import to_module_name, to_path

package_path = Path(pyrig.__path__[0])

custom_plugin_path = to_path("tests.base.fixtures", is_package=True)
package_plugin_path = (
    package_path / to_path("utils.testing", is_package=True) / custom_plugin_path
)

custom_plugin_module_names = [
    to_module_name(path) for path in custom_plugin_path.rglob("*.py")
]

package_plugin_module_names = [
    to_module_name(path.relative_to(package_path.parent))
    for path in package_plugin_path.rglob("*.py")
]


pytest_plugins = [
    *package_plugin_module_names,
    *custom_plugin_module_names,
]
